@@ -1,7 +1,7 @@
 use core::{fmt, ops::Deref};
 use std::io::Read;
 
-use csv::{Error as CsvError, Reader as CsvReader};
+use csv::{Error as CsvError, Reader};
 
 use crate::record::Record;
 
@@ -27,12 +27,11 @@ impl Deref for Records {
 //
 impl Records {
     pub fn from_csv<R: Read>(rdr: R) -> Result<Self, RecordsFromCsvError> {
-        let mut rdr = CsvReader::from_reader(rdr);
-        let iter = rdr.records();
+        let mut rdr = Reader::from_reader(rdr);
 
         let mut inner = vec![];
 
-        for record in iter {
+        for record in rdr.records() {
             let record = record.map_err(RecordsFromCsvError::CsvParseFailed)?;
             let row: Record = record
                 .deserialize(None)
